==> osmo_0.2.2.orig.tar.gz: osmo-0.2.2/src/credits.h <==

/*
 * Osmo - a handy personal organizer
 *
 * Copyright (C) 2007 Tomasz Maka <pasp@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _CREDITS_H
#define _CREDITS_H

#include <glib.h>

typedef struct {
	gchar *tag;
	gchar *name;
	gchar *email;
} OsmoCreditEntry;

static OsmoCreditEntry credits_programming[] = {
	{ NULL, "Tomasz Mąka", "pasp@users.sourceforge.net" }
};

static OsmoCreditEntry credits_graphics[] = {
	{ NULL, "Maja Kocoń", "http://ironya.ll.pl" }
};

static OsmoCreditEntry credits_contributors[] = {
	{ NULL, "Piotr Mąka", "silloz@users.sourceforge.net" },
	{ NULL, "Markus Dahms", "mad@automagically.de" }
};

static OsmoCreditEntry credits_translators[] = {
	{ "cs", "Jaroslav Lichtblau", "dragonlord@seznam.cz" },
	{ "de", "Markus Dahms", "mad@automagically.de" },
	{ "es", "Nacho Alonso González", "nacho.alonso.gonzalez@gmail.com" },
	{ "fr", "Jean-Jacques Moulinier", "postmaster@moulinier.net" },
	{ "hu", "Peter Polonkai", "polesz@nedudu.hu" },
	{ "it", "Bautz", "bautz@email.com" },
	{ "lt", "Vaidotas Kazla", "joshas@gmail.com" },
	{ "nl", "Tiger!P", "tigerp@tigerp.net" },
	{ "pl", "Piotr Mąka", "silloz@users.sourceforge.net" },
	{ "pt", "Bruno Miguel", "brunoalexandremiguel@gmail.com" },
    { "ru", "Vyacheslav A. Trishkin", "dedovsk@mail.ru" },
    { "zh", "Sasaqqdan", "sasaqqdan@gmail.com" }
};

#endif

==> osmo_0.2.4.orig.tar.gz: osmo-0.2.4/src/credits.h <==

/*
 * Osmo - a handy personal organizer
 *
 * Copyright (C) 2007 Tomasz Maka <pasp@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _CREDITS_H
#define _CREDITS_H

#include <glib.h>

typedef struct {
	gchar *tag;
	gchar *name;
	gchar *email;
} OsmoCreditEntry;

static OsmoCreditEntry credits_programming[] = {
	{ NULL, "Tomasz Mąka", "pasp@users.sourceforge.net" },
	{ NULL, "Piotr Mąka", "silloz@users.sourceforge.net" }
};

static OsmoCreditEntry credits_graphics[] = {
	{ NULL, "Maja Kocoń", "http://ironya.ll.pl" }
};

static OsmoCreditEntry credits_contributors[] = {
	{ NULL, "Markus Dahms", "mad@automagically.de" }
};

static OsmoCreditEntry credits_translators[] = {
	{ "cs", "Jaroslav Lichtblau", "dragonlord@seznam.cz" },
	{ "de", "Markus Dahms", "mad@automagically.de" },
	{ "es", "Nacho Alonso González", "nacho.alonso.gonzalez@gmail.com" },
	{ "fr", "Jean-Jacques Moulinier", "postmaster@moulinier.net" },
	{ "hu", "Peter Polonkai", "polesz@nedudu.hu" },
	{ "it", "Bautz", "bautz@email.com" },
	{ "ja", "Norihiro YONEDA", "aoba@avis.ne.jp" },
	{ "lt", "Vaidotas Kazla", "joshas@gmail.com" },
	{ "nl", "Tiger!P", "tigerp@tigerp.net" },
	{ "pl", "Piotr Mąka", "silloz@users.sourceforge.net" },
	{ "pt", "Bruno Miguel", "brunoalexandremiguel@gmail.com" },
    { "ru", "Vyacheslav A. Trishkin", "dedovsk@mail.ru" },
    { "tr", "Hasan Yılmaz", "hasanyilmaz@users.sourceforge.net" },
    { "zh", "Sasaqqdan", "sasaqqdan@gmail.com" }
};

#endif
